@@ -1,20 +1,19 @@
 """
 Type annotations for secretsmanager service client paginators.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html)
 
 Usage::
 
     ```python
-    from boto3.session import Session
+    import boto3
 
-    from mypy_boto3_secretsmanager.client import SecretsManagerClient
+    from mypy_boto3_secretsmanager import SecretsManagerClient
     from mypy_boto3_secretsmanager.paginator import (
         ListSecretsPaginator,
     )
 
-    session = Session()
-    client: SecretsManagerClient = session.client("secretsmanager")
+    client: SecretsManagerClient = boto3.client("secretsmanager")
 
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
     ```
@@ -42,8 +41,8 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators/#listsecretspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
     def paginate(
@@ -51,9 +50,9 @@ class ListSecretsPaginator(Boto3Paginator):
         *,
         Filters: Sequence["FilterTypeDef"] = ...,
         SortOrder: SortOrderTypeType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators/#listsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
